# 0.2.0 2021-09-23

- Choose the output format at the command line interface
- Accepting gender parameter from some kingraph examples
- Display divorced and married dates at the same time
- Fix: using ids diferent than the fullname, splitted the person
- Fix: Play nice with parentless families

# 0.1.1 2021-09-11

- Packaging and documentation

# 0.1.0 2021-09-11 

- First public release



